--[[
Interface: 1.5.1.0 b1580

Author: GtX | Andy

Support: https://ls-modcompany.com

Date: 18.06.2018

Version: 1.0.0.0 @ 18.06.2018 - Release

About: Allows the addition of custom pipe state names when more than two states are used.

----------------------------------------------------------------------------------------------------------------

*********************
** modDesc example **
*********************

	<l10n>
        <text name="action_unfoldPipe">
            <en>Unfold Pipe</en>
			<de>Rohr ausklappen</de>
        </text>
		<text name="info_pipeRight">
            <en>Current Pipe State: Right</en>
			<de>Aktuellen Zustand: Recht</de>
        </text>
        <text name="info_pipeLeft">
            <en>Current Pipe State: Left</en>
			<de>Aktuellen Zustand: Links</de>
        </text>
        <text name="info_stateChanging">
            <en>Pipe Moving...</en>
            <de>Rohrbewegung...</de>
        </text>
    </l10n>

	<specializations>
		<specialization name="pipeStatesDraw" className="PipeStatesDraw" filename="PipeStatesDraw.lua"/>
    </specializations>

*********************
** xml example **
*********************

	<vehicle>
		<pipeStateDraw stateChangeText="info_stateChanging" >
			<state1 text="action_unfoldPipe" />
			<state2 text="info_pipeRight" />
			<state3 text="info_pipeLeft" />
		</pipeStateDraw>
	</vehicle>

----------------------------------------------------------------------------------------------------------------
]]

PipeStatesDraw = {};

function PipeStatesDraw.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Pipe, specializations)
end

function PipeStatesDraw:load(savegame)
	self.pipeStateDraw = {};

	if self.pipeNumStates > 2 then
		for state = 1, self.pipeNumStates do
            local stateKey = string.format("vehicle.pipeStateDraw.state%d", state);
			local text = "modHub_error";
			if hasXMLProperty(self.xmlFile, stateKey) then
				text = getXMLString(self.xmlFile, stateKey.."#text");
			else
				print("Error: [PipeStatesDraw] 'state"..tostring(state).."' not found at 'vehicle.pipeStateDraw'");
			end;

			self.pipeStateDraw[state] = g_i18n:getText(text);
		end;

		self.stateChangingText = g_i18n:getText(Utils.getNoNil(getXMLString(self.xmlFile, "vehicle.pipeStateDraw#stateChangeText"), "modHub_error"));
	else
		print("Error: [PipeStatesDraw] Only "..tostring(self.pipeNumStates).." pipe states found, minimum 3 pipe states are required.");
	end;
end;

function PipeStatesDraw:delete()
end;

function PipeStatesDraw:update(dt)
end;

function PipeStatesDraw:draw()
	 if self.isClient and self:getIsActiveForInput(true) and not self:hasInputConflictWithSelection() then
        if self.hasPipe then
            if self.pipeNumStates > 2 then
				if self.pipeCurrentState == 0 then
					g_currentMission:addHelpButtonText(self.stateChangingText, InputBinding.TOGGLE_PIPE, nil, GS_PRIO_HIGH);
				else
					local state = self.pipeStateDraw[self.pipeCurrentState];
					g_currentMission:addHelpButtonText(state, InputBinding.TOGGLE_PIPE, nil, GS_PRIO_HIGH);
				end;
            end;
        end;
    end;
end;

function PipeStatesDraw:mouseEvent(posX, posY, isDown, isUp, button)
end;

function PipeStatesDraw:keyEvent(unicode, sym, modifier, isDown)
end;